package de.ozgcloud.archive.common.xta;

import java.util.List;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.Resource;

import de.ozgcloud.xta.client.model.XtaIdentifier;
import lombok.Getter;
import lombok.Setter;

@Configuration
@ConfigurationProperties(prefix = XtaProperties.XTA_PROPERTIES_PREFIX)
@Getter
@Setter
public class XtaProperties {

	public static final String XTA_PROPERTIES_PREFIX = "ozgcloud.xta";

	/*
	 * Flag to enable/disable XTA adapter usage.
	 */
	private boolean enabled = false;
	/*
	 * XTA endpoint messages are sent to.
	 */
	private String sendServiceUrl;
	/*
	 * XTA endpoint to message box.
	 */
	private String msgBoxServiceUrl;
	/*
	 * XTA endpoint to management information
	 */
	private String managementServiceUrl;
	/*
	 * Maximum number of messages loaded from message box.
	 */
	private int maxLoadedMessages = 50;
	/*
	 * Reference to client certification key store.
	 */
	private XtaClientKeyStore keyStore;
	/*
	 * Reference to trust store.
	 */
	private XtaClientKeyStore trustStore;
	/*
	 * Client identifiers used to identify client at XTA adapter.
	 */
	private List<XtaIdentifier> clientIdentifiers;
	/*
	 * Times in cron format at which Quittungen are fetched. Default is set to every
	 * 15 minutes.
	 */
	private String schedulerCron = "0 0/15 * * * *";

	@Getter
	@Setter
	public static class XtaClientKeyStore {
		/*
		 * Reference to key store reference.
		 */
		private Resource file;
		/*
		 * Type of the referenced key store.
		 */
		private String type;
		/*
		 * Password to access key store.
		 */
		private char[] password;
	}
}
