package de.ozgcloud.archive.common.xta;

import java.util.Optional;
import java.util.function.Consumer;

import org.springframework.stereotype.Service;

import de.ozgcloud.common.errorhandling.TechnicalException;
import de.ozgcloud.xta.client.XtaClient;
import de.ozgcloud.xta.client.exception.XtaClientException;
import de.ozgcloud.xta.client.model.XtaFile;
import de.ozgcloud.xta.client.model.XtaMessage;
import de.ozgcloud.xta.client.xdomea.XdomeaXtaMessageCreator;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@RequiredArgsConstructor
@Service
public class XtaService {
	private static final String XTA_CLIENT_IS_NOT_CONFIGURED_MESSAGE = "XtaClient is not configured! Cannot send message to DMS.";

	private final Optional<XtaClient> xtaClient;

	public void sendXdomeaFile(XtaFile xdomeaFile) {
		try {
			getXtaClient().sendMessage(createMessage(xdomeaFile));
		} catch (XtaClientException e) {
			throw new TechnicalException("Error on sending xDomea message!", e);
		}
	}

	XtaMessage createMessage(XtaFile xdomeaFile) {
		try {
			return XdomeaXtaMessageCreator.createInstance().createMessage(xdomeaFile);
		} catch (XtaClientException e) {
			throw new TechnicalException("Error on creating xDomea message!", e);
		}
	}

	XtaClient getXtaClient() {
		return xtaClient.orElseThrow(() -> new TechnicalException(XTA_CLIENT_IS_NOT_CONFIGURED_MESSAGE));
	}

	public void fetchMessages(Consumer<XtaMessage> messageConsumer) {
		try {
			getXtaClient().fetchMessages(messageConsumer);
		} catch (XtaClientException e) {
			throw new TechnicalException("Error fetching xta messages.", e);
		}
	}

}
