/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.export;

import java.util.UUID;

import org.springframework.core.task.TaskExecutor;

import com.google.protobuf.ByteString;

import de.ozgcloud.archive.ArchiveManagerConfiguration;
import de.ozgcloud.archive.grpc.export.ExportServiceGrpc.ExportServiceImplBase;
import de.ozgcloud.archive.grpc.export.GrpcExportVorgangRequest;
import de.ozgcloud.archive.grpc.export.GrpcExportVorgangResponse;
import de.ozgcloud.archive.grpc.export.GrpcFile;
import de.ozgcloud.common.binaryfile.GrpcBinaryFileServerDownloader;
import io.grpc.stub.CallStreamObserver;
import io.grpc.stub.StreamObserver;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService(interceptorNames = { ArchiveManagerConfiguration.CALL_CONTEXT_SERVER_INTERCEPTOR_NAME })
@RequiredArgsConstructor
class ExportGrpcService extends ExportServiceImplBase {

	private final ExportService exportService;
	private final TaskExecutor taskExecutor;

	@Override
	public void exportVorgang(GrpcExportVorgangRequest request, StreamObserver<GrpcExportVorgangResponse> responseObserver) {
		var fileNameId = createFileNameId();
		sendFileName(responseObserver, fileNameId);
		buildExportDownloader(request.getVorgangId(), fileNameId, responseObserver).start();
	}

	String createFileNameId() {
		return UUID.randomUUID().toString();
	}

	void sendFileName(StreamObserver<GrpcExportVorgangResponse> responseObserver, String fileNameId) {
		responseObserver.onNext(GrpcExportVorgangResponse.newBuilder()
				.setVorgangFile(GrpcFile.newBuilder().setFileName(exportService.buildXdomeaFileName(fileNameId)).build())
				.build());
	}

	GrpcBinaryFileServerDownloader<GrpcExportVorgangResponse> buildExportDownloader(String vorgangId, String fileNameId,
			StreamObserver<GrpcExportVorgangResponse> responseObserver) {
		return GrpcBinaryFileServerDownloader.<GrpcExportVorgangResponse>builder()
				.callObserver((CallStreamObserver<GrpcExportVorgangResponse>) responseObserver)
				.taskExecutor(taskExecutor)
				.downloadConsumer(outputStream -> exportService.writeXdomeaFileContent(vorgangId, fileNameId, outputStream))
				.chunkBuilder(this::buildExportVorgangChunkResponse)
				.build();
	}

	GrpcExportVorgangResponse buildExportVorgangChunkResponse(ByteString chunk) {
		return GrpcExportVorgangResponse.newBuilder()
				.setVorgangFile(GrpcFile.newBuilder().setFileContent(chunk).build())
				.build();
	}
}
