/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.file;

import java.io.OutputStream;
import java.util.List;
import java.util.concurrent.atomic.AtomicLong;
import java.util.stream.Stream;

import org.springframework.stereotype.Service;

import de.ozgcloud.archive.common.binaryfile.BinaryFileService;
import de.ozgcloud.archive.vorgang.VorgangWithEingang;
import de.ozgcloud.common.binaryfile.FileId;
import de.xoev.xdomea.DokumentType;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@Service
public class ExportFileService {

	private final OzgFileRemoteService ozgFileRemoteService;
	private final BinaryFileService binaryFileService;

	public Stream<OzgFile> getRepresentations(VorgangWithEingang vorgang) {
		return ozgFileRemoteService.getRepresentations(vorgang.getId());
	}

	public Stream<OzgFile> getAttachments(VorgangWithEingang vorgang) {
		return ozgFileRemoteService.getAttachments(vorgang.getId());
	}

	public Stream<DokumentType> createDokumentTypes(List<OzgFile> ozgFiles, String formEngineName) {
		var ordinalNumberGenerator = new AtomicLong(1);
		return ozgFiles.stream().map(ozgFile -> DokumentTypeBuilder.builder()
				.withOrdinalNumber(ordinalNumberGenerator.getAndIncrement())
				.withFormEngineName(formEngineName)
				.withOzgFile(ozgFile)
				.build());
	}

	public void writeOzgFile(FileId fileId, OutputStream outputStream) {
		binaryFileService.writeFileContent(fileId, outputStream);
	}

}
