/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.historie;

import java.util.Optional;

import org.apache.commons.lang3.StringUtils;

import de.ozgcloud.archive.common.command.ArchiveManagerCommand;
import de.ozgcloud.archive.common.command.CommandWithPrevious;
import de.ozgcloud.archive.common.user.UserProfile;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
class AssignedUserChangeHistoryBuilder extends ChangeHistoryBuilder<AssignedUserChangeHistoryBuilder> {

	static final String BODY_PROPERTY_ASSIGNED_USER = "assignedTo";
	static final String ASSIGN_USER_ORDER = "ASSIGN_USER";

	private UserProfileCache userProfileCache;

	public static AssignedUserChangeHistoryBuilder builder() {
		return new AssignedUserChangeHistoryBuilder();
	}

	public AssignedUserChangeHistoryBuilder withUserProfileCache(UserProfileCache userProfileCache) {
		this.userProfileCache = userProfileCache;
		return this;
	}

	@Override
	boolean isRelevant(ArchiveManagerCommand command) {
		return ASSIGN_USER_ORDER.equals(command.getOrder());
	}

	@Override
	CommandWithChangeValues toCommandWithChangeValues(CommandWithPrevious commandWithPrevious) {
		return new CommandWithChangeValues(
				commandWithPrevious.getCommand(),
				getAssignedUserBeforeChange(commandWithPrevious),
				getAssignedUserAfterChange(commandWithPrevious));
	}

	String getAssignedUserBeforeChange(CommandWithPrevious commandWithPrevious) {
		return Optional.ofNullable(commandWithPrevious.getPrevious())
				.map(this::getAssignedUserFullNameFromCommand)
				.orElse(StringUtils.EMPTY);
	}

	String getAssignedUserAfterChange(CommandWithPrevious commandWithPrevious) {
		return getAssignedUserFullNameFromCommand(commandWithPrevious.getCommand());
	}

	String getAssignedUserFullNameFromCommand(ArchiveManagerCommand command) {
		var assignedUserId = getValueFromCommandBodyObject(BODY_PROPERTY_ASSIGNED_USER, command);
		return userProfileCache.getUserProfile(assignedUserId).map(UserProfile::getFullName).orElse("automatisch");
	}
}
