/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.historie;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;
import java.util.function.Function;

import de.ozgcloud.archive.common.user.UserProfile;
import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.AccessLevel;
import lombok.RequiredArgsConstructor;

//TODO OZG-7379 remove this cache
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
class UserProfileCache {

	private final Function<String, Optional<UserProfile>> findUserProfileForUserId;

	private final Map<String, Optional<UserProfile>> cache = new HashMap<>();

	public static UserProfileCache create(Function<String, Optional<UserProfile>> findUserProfileForUserId) {
		return new UserProfileCache(findUserProfileForUserId);
	}

	public Optional<UserProfile> getUserProfile(String userId) {
		if (!cache.containsKey(userId)) {
			findAndAddToCache(userId);
		}
		return cache.get(userId);
	}

	private void findAndAddToCache(String userId) {
		var userProfile = findUserProfileForUserId.apply(userId);
		if (userProfile == null) {
			throw new TechnicalException("UserProfile not found for user with ID " + userId);
		}
		cache.put(userId, userProfile);
	}
}
