/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.postfach;

import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.MappingConstants;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.ValueMapping;

import com.google.protobuf.ProtocolStringList;

import de.ozgcloud.archive.common.TimeMapper;
import de.ozgcloud.common.binaryfile.FileId;
import de.ozgcloud.nachrichten.postfach.GrpcPostfachMail;

@Mapper(nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS, uses = TimeMapper.class, imports = StringUtils.class)
interface PostfachMailMapper {

	@Mapping(target = "attachment", ignore = true)

	@ValueMapping(target = MappingConstants.NULL, source = "UNRECOGNIZED")
	@ValueMapping(target = MappingConstants.NULL, source = "UNDEFINED")
	@Mapping(target = "attachments", source = "attachmentList")
	@Mapping(target = "createdBy", expression = "java(StringUtils.trimToNull(grpcPostfachMail.getCreatedBy()))")
	PostfachMail toPostfachMail(GrpcPostfachMail grpcPostfachMail);

	default List<FileId> fromStringList(ProtocolStringList stringList) {
		return stringList.stream().map(FileId::from).toList();
	}
}