/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import java.util.HashMap;
import java.util.Map;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
class WrappedValueExtractor {

	static final String WRAPPER_KEY = "value";

	public static Map<String, Object> extractWrappedValues(Map<String, Object> formData) {
		Map<String, Object> result = new HashMap<>();
		for (var entry : formData.entrySet()) {
			result.put(entry.getKey(), replaceWrappedValueWithDirectValue(entry.getValue()));
		}
		return result;
	}

	@SuppressWarnings("unchecked")
	static Object replaceWrappedValueWithDirectValue(Object value) {
		if (!(value instanceof Map)) {
			return value;
		}
		Map<String, Object> formData = (Map<String, Object>) value;
		return isWrappedValue(formData) ? replaceWrappedValueWithDirectValue(formData.get(WRAPPER_KEY)) : extractWrappedValues(formData);
	}

	static boolean isWrappedValue(Map<String, Object> formData) {
		return formData.containsKey(WRAPPER_KEY) && formData.size() == 1;
	}
}
