/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common.command;

import java.time.ZonedDateTime;
import java.util.Map;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.archive.common.user.UserProfileTestFactory;
import de.ozgcloud.command.CommandStatus;

public class CommandTestFactory {

	public static final String ID = UUID.randomUUID().toString();
	public static final String VORGANG_ID = UUID.randomUUID().toString();;

	public static final String CREATED_BY_NAME = UserProfileTestFactory.FULLNAME;
	public static final String ORDER = LoremIpsum.getInstance().getWords(1);
	public static final CommandStatus STATUS = CommandStatus.FINISHED;

	public static final String BODY_FIELD_NAME = LoremIpsum.getInstance().getWords(1);
	public static final String BODY_FIELD_VALUE = LoremIpsum.getInstance().getWords(1);
	public static final Map<String, Object> BODY = Map.of(BODY_FIELD_NAME, BODY_FIELD_VALUE);

	public static final String RELATION_ID = UUID.randomUUID().toString();
	public static final long RELATION_VERSION = 42;

	public static final String CREATED_AT_STR = "2023-08-18T13:54:10Z";
	public static final ZonedDateTime CREATED_AT = ZonedDateTime.parse(CREATED_AT_STR);
	public static final String FINISHED_AT_STR = "2023-08-18T13:55:10Z";
	public static final ZonedDateTime FINISHED_AT = ZonedDateTime.parse(FINISHED_AT_STR);

	public static final String CREATED_RESOURCE = UUID.randomUUID().toString();
	public static final String CREATED_BY = UUID.randomUUID().toString();
	public static final String ERROR_MESSAGE = "An error occurred";

	public static ArchiveManagerCommand create() {
		return createBuilder().build();
	}

	public static ArchiveManagerCommand.ArchiveManagerCommandBuilder createBuilder() {
		return ArchiveManagerCommand.builder()
				.id(ID)
				.vorgangId(VORGANG_ID)
				.relationId(RELATION_ID)
				.order(ORDER)
				.status(STATUS)
				.createdAt(CREATED_AT)
				.finishedAt(FINISHED_AT)
				.bodyObject(BODY)
				.createdResource(CREATED_RESOURCE)
				.createdBy(CREATED_BY)
				.createdByName(CREATED_BY_NAME)
				.errorMessage(ERROR_MESSAGE);
	}
}