package de.ozgcloud.archive.common.xta;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;
import org.mockito.MockedStatic;

import de.ozgcloud.archive.common.xta.XtaImportConfirmationHandler.XtaAbgabeAdapter;
import de.ozgcloud.common.test.ReflectionTestUtils;
import de.ozgcloud.xta.client.model.XtaFile;
import de.xoev.xdomea.AbgabeImportBestaetigen0402;

class XtaImportConfirmationHandlerTest {

	@DisplayName("Xta import confirmation handler")
	@Nested
	class TestXtaImportConfirmationHandler {

		private final AbgabeImportBestaetigen0402 importConfirmation = AbgabeImportBestaetigen0402TestFactory.create();
		private final XtaFile file = XtaFileTestFactory.create(AbgabeImportBestaetigen0402TestFactory.FILE_PATH);

		@Mock
		private XtaFileReader<AbgabeImportBestaetigen0402> reader;

		@Nested
		class TestCreateFrom {

			@SuppressWarnings("rawtypes")
			private MockedStatic<XtaFileReader> fileReaderStaticMock;

			@BeforeEach
			void initMock() {
				fileReaderStaticMock = mockStatic(XtaFileReader.class);
				fileReaderStaticMock.when(XtaFileReader::createAbgabeImportBestaetigen0402Reader).thenReturn(reader);
			}

			@AfterEach
			void closeMock() {
				fileReaderStaticMock.close();
			}

			@Test
			void shouldReadFileContent() {
				XtaImportConfirmationHandler.createFrom(file);

				verify(reader).read(file);
			}

			@Test
			void shouldSetImportConfirmation() {
				when(reader.read(any())).thenReturn(importConfirmation);

				var confiHandler = XtaImportConfirmationHandler.createFrom(file);

				assertThat(ReflectionTestUtils.getField(confiHandler, "importConfirmation", AbgabeImportBestaetigen0402.class))
						.usingRecursiveComparison().isEqualTo(importConfirmation);

			}

		}

		@Nested
		class TestGetAbgaben {
			private final XtaFile file = XtaFileTestFactory.create(AbgabeImportBestaetigen0402TestFactory.FILE_PATH);

			@Test
			void shouldReturnAbgabenAsHandler() {
				var handler = XtaImportConfirmationHandler.createFrom(file);

				assertThat(handler.getAbgaben()).hasSize(1);
				assertThat(handler.getAbgaben().findFirst()).isPresent().get().isInstanceOf(XtaAbgabeAdapter.class);
			}
		}
	}

	@DisplayName("Xta abgabe handler")
	@Nested
	class TestXtaAbgabeAdapter {

		private final XtaFile file = XtaFileTestFactory.create(AbgabeImportBestaetigen0402TestFactory.FILE_PATH);

		@Test
		void shouldReturnVorgangId() {
			var vorgangId = initAbgabeHandler().getVorgangId();

			assertThat(vorgangId).isEqualTo(AbgabeImportBestaetigen0402TestFactory.VORGANG_ID);
		}

		@Test
		void shouldReturnIsSucessful() {
			var isSuccessful = initAbgabeHandler().isSuccessful();

			assertThat(isSuccessful).isEqualTo(AbgabeImportBestaetigen0402TestFactory.ERFOLGREICH);
		}

		@Test
		void shouldReturnErrorMessage() {
			var errorMessage = initAbgabeHandler().getErrorMessage();

			assertThat(errorMessage).isEqualTo(AbgabeImportBestaetigen0402TestFactory.FEHLERMELDUNG);
		}

		private XtaAbgabeAdapter initAbgabeHandler() {
			return initImportConfirmationHandler().getAbgaben().findFirst().get();
		}

		private XtaImportConfirmationHandler initImportConfirmationHandler() {
			return XtaImportConfirmationHandler.createFrom(file);
		}
	}
}