/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.export;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.MockedStatic;

import de.ozgcloud.archive.common.ExportFilenameGenerator;
import de.ozgcloud.archive.common.UUIDConverter;
import de.ozgcloud.archive.common.XDomeaTestUtils;
import de.ozgcloud.archive.file.OzgFile;
import de.ozgcloud.archive.file.OzgFileTestFactory;

class ExportFilenameGeneratorTest {

	private MockedStatic<UUIDConverter> uuidConverter;

	@Nested
	class TestGenerateExportFilename {

		private static final String UUID = "64a820d3-6285-172a-c028-0000000026d0";

		private final OzgFile ozgFile = OzgFileTestFactory.create();

		@BeforeEach
		void init() {
			uuidConverter = mockStatic(UUIDConverter.class);
			uuidConverter.when(() -> UUIDConverter.fromObjectId(ozgFile.getId().toString())).thenReturn(UUID);
		}

		@AfterEach
		void cleanup() {
			uuidConverter.close();
		}

		@Test
		void shouldConvertObjectId() {
			callGenerator();

			uuidConverter.verify(() -> UUIDConverter.fromObjectId(ozgFile.getId().toString()));
		}

		@Test
		void shouldGenerate() {
			var filename = callGenerator();

			assertThat(filename).matches(String.format("^%s_%s$", XDomeaTestUtils.UUID_REGEX, ozgFile.getName()));
		}

		private String callGenerator() {
			return ExportFilenameGenerator.generateExportFilename(ozgFile);
		}
	}

}