/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.kommentar;

import java.util.List;
import java.util.Map;

import de.ozgcloud.vorgang.common.GrpcObject;
import de.ozgcloud.vorgang.common.GrpcProperty;
import de.ozgcloud.vorgang.vorgangAttachedItem.GrpcVorgangAttachedItem;

public class GrpcKommentarTestFactory {

	public static final String KEY_ID = "id";
	public static final String KEY_TEXT = "text";
	public static final String KEY_CREATED_BY = "createdBy";
	public static final String KEY_CREATED_AT = "createdAt";
	public static final String KEY_ATTACHMENTS = "attachments";

	public static final List<String> ATTACHMENTS = List.of(KommentarTestFactory.ATTACHMENT_FILE_ID.toString());

	public static final GrpcObject ITEM = createItemBuilder().build();

	public static GrpcVorgangAttachedItem create() {
		return createBuilder().build();
	}

	public static GrpcVorgangAttachedItem.Builder createBuilder() {
		return GrpcVorgangAttachedItem.newBuilder()
				.setItem(ITEM);
	}

	public static GrpcObject.Builder createItemBuilder() {
		return GrpcObject.newBuilder()
				.addProperty(GrpcProperty.newBuilder().setName(KEY_ID).addValue(KommentarTestFactory.ID))
				.addProperty(GrpcProperty.newBuilder().setName(KEY_TEXT).addValue(KommentarTestFactory.TEXT))
				.addProperty(GrpcProperty.newBuilder().setName(KEY_CREATED_BY).addValue(KommentarTestFactory.CREATED_BY))
				.addProperty(GrpcProperty.newBuilder().setName(KEY_CREATED_AT).addValue(KommentarTestFactory.CREATED_AT_STR))
				.addProperty(GrpcProperty.newBuilder().setName(KEY_ATTACHMENTS).addAllValue(ATTACHMENTS));
	}

	public static Map<String, Object> createItemAsMap() {
		return Map.of(
				KEY_ID, KommentarTestFactory.ID,
				KEY_TEXT, KommentarTestFactory.TEXT,
				KEY_CREATED_BY, KommentarTestFactory.CREATED_BY,
				KEY_CREATED_AT, KommentarTestFactory.CREATED_AT_STR,
				KEY_ATTACHMENTS, ATTACHMENTS);
	}
}
