/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.kommentar;

import java.time.ZonedDateTime;
import java.util.Collections;
import java.util.List;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.archive.common.XDomeaTestUtils;
import de.ozgcloud.common.binaryfile.FileId;

public class KommentarTestFactory {
	public static final String ID = XDomeaTestUtils.createMongoDbObjectId();

	public static final String CREATED_BY = UUID.randomUUID().toString();
	public static final String CREATED_AT_STR = "2021-01-10T10:30:00Z";
	public static final ZonedDateTime CREATED_AT = ZonedDateTime.parse(CREATED_AT_STR);

	public static final String TEXT = LoremIpsum.getInstance().getWords(15);

	public static final FileId ATTACHMENT_FILE_ID = FileId.from(UUID.randomUUID().toString());
	public static final List<FileId> ATTACHMENTS = Collections.singletonList(ATTACHMENT_FILE_ID);

	public static final Kommentar KOMMENTAR = create();

	public static Kommentar create() {
		return createBuilder().build();
	}

	public static Kommentar.KommentarBuilder createBuilder() {
		return Kommentar.builder()
				.id(ID)
				.text(TEXT)
				.attachments(ATTACHMENTS)
				.createdBy(CREATED_BY)
				.createdAt(CREATED_AT);
	}
}
