/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import java.util.List;

import de.xoev.xdomea.AntragsdatenGroupType;
import de.xoev.xdomea.AntragsdatenItemType;
import de.xoev.xdomea.AntragsdatenMultiValueFieldType;
import de.xoev.xdomea.AntragsdatenSingleValueFieldType;
import de.xoev.xdomea.DatatypeType;

public class AntragsdatenItemTypeTestFactory {

	public static final String KEY_STRING = "string";
	public static final String KEY_MAP = "map";
	public static final String KEY_COLLECTION = "collection";
	public static final String VALUE_STRING = "value1";
	public static final Integer VALUE_INTEGER = 1;

	public static AntragsdatenSingleValueFieldType createSingleValueField() {
		var antragsdatenItemType = new AntragsdatenSingleValueFieldType();
		antragsdatenItemType.setType(DatatypeType.STRING);
		antragsdatenItemType.setName(KEY_STRING);
		antragsdatenItemType.setValue(VALUE_STRING);
		return antragsdatenItemType;
	}

	public static AntragsdatenMultiValueFieldType createMultiValueField() {
		var antragsdatenItemType = new AntragsdatenMultiValueFieldType();
		antragsdatenItemType.setType(DatatypeType.INTEGER);
		antragsdatenItemType.setName(KEY_COLLECTION);
		antragsdatenItemType.getValue().add(VALUE_INTEGER);
		return antragsdatenItemType;
	}

	public static AntragsdatenGroupType createGroup() {
		var antragsdatenGroupType = new AntragsdatenGroupType();
		antragsdatenGroupType.setName(KEY_MAP);

		antragsdatenGroupType.getItem().addAll(createAntragsdatenItemTypes());

		return antragsdatenGroupType;
	}

	public static List<AntragsdatenItemType> createAntragsdatenItemTypes() {
		return List.of(createMultiValueField(), createSingleValueField());
	}
}
