/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;

import de.xoev.xdomea.NameNatuerlichePersonType;

class NameNatuerlichePersonTypeCreatorTest {

	@InjectMocks
	private NameNatuerlichePersonTypeCreator creator;

	@Nested
	class TestCreate {

		@Test
		void shouldHaveAnrede() {
			var nameNatuerlichePerson = callCreator(AntragstellerTestFactory.create());

			assertThat(nameNatuerlichePerson.getAnrede()).isEqualTo(AntragstellerTestFactory.ANREDE);
		}

		@Test
		void shouldHaveEmptyAnrede() {
			var nameNatuerlichePerson = callCreator(AntragstellerTestFactory.createBuilder().anrede(null).build());

			assertThat(nameNatuerlichePerson.getAnrede()).isEmpty();
		}

		@Test
		void shouldHaveVorname() {
			var nameNatuerlichePerson = callCreator(AntragstellerTestFactory.create());

			assertThat(nameNatuerlichePerson.getVorname().getName()).isEqualTo(AntragstellerTestFactory.VORNAME);
		}

		@Test
		void shouldHaveEmptyVorname() {
			var nameNatuerlichePerson = callCreator(AntragstellerTestFactory.createBuilder().vorname(null).build());

			assertThat(nameNatuerlichePerson.getVorname().getName()).isEmpty();
		}

		@Test
		void shouldHaveFamilienname() {
			var nameNatuerlichePerson = callCreator(AntragstellerTestFactory.create());

			assertThat(nameNatuerlichePerson.getFamilienname().getName()).isEqualTo(AntragstellerTestFactory.NACHNAME);
		}

		@Test
		void shouldHaveEmptyFamilienname() {
			var nameNatuerlichePerson = callCreator(AntragstellerTestFactory.createBuilder().nachname(null).build());

			assertThat(nameNatuerlichePerson.getFamilienname().getName()).isEmpty();
		}

		@Nested
		class TestWhenNullAntragsteller {

			@Test
			void shouldHaveEmptyAnrede() {
				var nameNatuerlichePerson = callCreator(null);

				assertThat(nameNatuerlichePerson.getAnrede()).isEmpty();
			}

			@Test
			void shouldHaveEmptyVorname() {
				var nameNatuerlichePerson = callCreator(null);

				assertThat(nameNatuerlichePerson.getVorname().getName()).isEmpty();
			}

			@Test
			void shouldHaveEmptyFamilienname() {
				var nameNatuerlichePerson = callCreator(null);

				assertThat(nameNatuerlichePerson.getFamilienname().getName()).isEmpty();
			}
		}

		private NameNatuerlichePersonType callCreator(Antragsteller antragsteller) {
			return creator.create(antragsteller);
		}
	}

}