/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import static de.ozgcloud.archive.vorgang.WrappedValueExtractor.*;
import static org.assertj.core.api.Assertions.*;

import java.util.Map;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

public class WrappedValueExtractorITCase {

	@Nested
	class TestExtractWrappedValues {

		@Test
		void shouldPreserveWrapperKeyWithoutParent() {
			Map<String, Object> formData = Map.of(WRAPPER_KEY, "Kiel");

			var formDataWithoutValueKeys = WrappedValueExtractor.extractWrappedValues(formData);

			assertThat(formDataWithoutValueKeys).isEqualTo(formData);
		}

		@Test
		void shouldEliminateWrapperKeyWithoutSiblings() {
			Map<String, Object> formData = Map.of("ort", Map.of(WRAPPER_KEY, "Kiel"));
			Map<String, Object> expected = Map.of("ort", "Kiel");

			var formDataWithoutValueKeys = WrappedValueExtractor.extractWrappedValues(formData);

			assertThat(formDataWithoutValueKeys).isEqualTo(expected);
		}

		@Test
		void shouldPreserveWrapperKeyIfHasSiblings() {
			Map<String, Object> formData = Map.of("ort", Map.of(WRAPPER_KEY, "Kiel", "value2", "Kiel"));

			var formDataWithoutValueKeys = WrappedValueExtractor.extractWrappedValues(formData);

			assertThat(formDataWithoutValueKeys).isEqualTo(formData);
		}

		@Test
		void shouldPreserveNonWrapperKeys() {
			Map<String, Object> formData = Map.of("empfangendestelle",
					Map.of(WRAPPER_KEY, Map.of("OrganisationseinheitenAuswahl", Map.of(WRAPPER_KEY, "123456"))));
			Map<String, Object> expected = Map.of("empfangendestelle", Map.of("OrganisationseinheitenAuswahl", "123456"));

			var formDataWithoutValueKeys = WrappedValueExtractor.extractWrappedValues(formData);

			assertThat(formDataWithoutValueKeys).isEqualTo(expected);
		}
	}
}
